@@ -327,8 +327,8 @@ __all__.append('SizeGroup')
 
 
 class MenuItem(Gtk.MenuItem):
-    def __init__(self, label=None):
-        super(MenuItem, self).__init__(label=label)
+    def __init__(self, label=None, **kwds):
+        super(MenuItem, self).__init__(label=label, **kwds)
 
 MenuItem = override(MenuItem)
 __all__.append('MenuItem')
@@ -387,8 +387,8 @@ __all__.append('Builder')
 # NOTE: This must come before any other Window/Dialog subclassing, to ensure
 # that we have a correct inheritance hierarchy.
 class Window(Gtk.Window):
-    def __init__(self, type=Gtk.WindowType.TOPLEVEL, **kwargs):
-        Gtk.Window.__init__(self, type=type, **kwargs)
+    def __init__(self, type=Gtk.WindowType.TOPLEVEL, **kwds):
+        Gtk.Window.__init__(self, type=type, **kwds)
 
 Window = override(Window)
 __all__.append('Window')
@@ -552,8 +552,8 @@ __all__.append('RecentChooserDialog')
 
 class IconView(Gtk.IconView):
 
-    def __init__(self, model=None):
-        Gtk.IconView.__init__(self, model=model)
+    def __init__(self, model=None, **kwds):
+        Gtk.IconView.__init__(self, model=model, **kwds)
 
     def get_item_at_pos(self, x, y):
         success, path, cell = super(IconView, self).get_item_at_pos(x, y)
@@ -576,8 +576,8 @@ __all__.append('IconView')
 
 class ToolButton(Gtk.ToolButton):
 
-    def __init__(self, stock_id=None):
-        Gtk.ToolButton.__init__(self, stock_id=stock_id)
+    def __init__(self, stock_id=None, **kwds):
+        Gtk.ToolButton.__init__(self, stock_id=stock_id, **kwds)
 
 ToolButton = override(ToolButton)
 __all__.append('ToolButton')
@@ -783,6 +783,12 @@ class TreeModel(Gtk.TreeModel):
         if success:
             return next_iter
 
+    def iter_previous(self, aiter):
+        prev_iter = aiter.copy()
+        success = super(TreeModel, self).iter_previous(prev_iter)
+        if success:
+            return prev_iter
+
     def iter_children(self, aiter):
         success, child_iter = super(TreeModel, self).iter_children(aiter)
         if success:
@@ -1429,15 +1435,15 @@ __all__.append('ScrolledWindow')
 
 
 class HScrollbar(Gtk.HScrollbar):
-    def __init__(self, adjustment=None):
-        Gtk.HScrollbar.__init__(self, adjustment=adjustment)
+    def __init__(self, adjustment=None, **kwds):
+        Gtk.HScrollbar.__init__(self, adjustment=adjustment, **kwds)
 
 HScrollbar = override(HScrollbar)
 __all__.append('HScrollbar')
 
 class VScrollbar(Gtk.VScrollbar):
-    def __init__(self, adjustment=None):
-        Gtk.VScrollbar.__init__(self, adjustment=adjustment)
+    def __init__(self, adjustment=None, **kwds):
+        Gtk.VScrollbar.__init__(self, adjustment=adjustment, **kwds)
 
 VScrollbar = override(VScrollbar)
 __all__.append('VScrollbar')
@@ -1454,9 +1460,10 @@ __all__.append('Paned')
 
 
 class Arrow(Gtk.Arrow):
-    def __init__(self, arrow_type, shadow_type):
+    def __init__(self, arrow_type, shadow_type, **kwds):
         Gtk.Arrow.__init__(self, arrow_type=arrow_type,
-                           shadow_type=shadow_type)
+                           shadow_type=shadow_type,
+                           **kwds)
 
 Arrow = override(Arrow)
 __all__.append('Arrow')
@@ -1475,9 +1482,10 @@ __all__.append('IconSet')
 
 
 class Viewport(Gtk.Viewport):
-    def __init__(self, hadjustment=None, vadjustment=None):
+    def __init__(self, hadjustment=None, vadjustment=None, **kwds):
         Gtk.Viewport.__init__(self, hadjustment=hadjustment,
-                              vadjustment=vadjustment)
+                              vadjustment=vadjustment,
+                              **kwds)
 
 Viewport = override(Viewport)
 __all__.append('Viewport')
